@@ -1,9 +1,14 @@
-from pydantic import BaseModel, Field
-from typing import Optional, List, Union
+from typing import Any, Dict, List, Optional, Union
+
+from pydantic import BaseModel
+
+from ..base_model import BaseResponseModel
+
 
 class BillableMetricGroup(BaseModel):
     key: Optional[str]
-    values: Optional[List[Union[str, dict]]]
+    values: Optional[List[Union[str, Dict[str, Any]]]]
+
 
 class BillableMetric(BaseModel):
     name: Optional[str]
@@ -13,7 +18,8 @@ class BillableMetric(BaseModel):
     field_name: Optional[str]
     group: Optional[BillableMetricGroup]
 
-class BillableMetricResponse(BaseModel):
+
+class BillableMetricResponse(BaseResponseModel):
     lago_id: str
     name: str
     code: str
@@ -24,3 +30,4 @@ class BillableMetricResponse(BaseModel):
     group: BillableMetricGroup
     active_subscriptions_count: int
     draft_invoices_count: int
+    plans_count: int
